RouteEntry

Struct RouteEntry 

pub struct RouteEntry {
    pub method: HttpMethod,
    pub path: &'static str,
    pub handler_type: &'static str,
    pub rsp_type: &'static str,
    pub summary: &'static str,
    pub description: &'static str,
    pub params: &'static [ParamMeta],
    pub required_role: &'static str,
}
A route entry registered at compile time via #[endpoint] (or its shortcuts #[get]/#[post]/…).

Collected by the inventory crate and read at application startup.

Fields

method: HttpMethod

HTTP method for this route.

path: &'static str

Route path pattern (e.g., “/users/{id}”).

handler_type: &'static str

Type name of the request handler. Used to dispatch to the correct handler at runtime.

rsp_type: &'static str

OpenAPI response type name (e.g., “UserModel”, “Vec”, “String”).

summary: &'static str

Human-readable summary for OpenAPI docs (e.g., “Get user by ID”).

description: &'static str

Optional long-form description from /// doc comments on the impl block.

params: &'static [ParamMeta]

OpenAPI parameter metadata: path params, body params, etc.

required_role: &'static str

“” = public, “authenticated” = any valid JWT, otherwise specific role name.

Implementations

Source

impl RouteEntry

pub const fn new( method: HttpMethod, path: &'static str, handler_type: &'static str, rsp_type: &'static str, summary: &'static str, description: &'static str, params: &'static [ParamMeta], required_role: &'static str, ) -> Self

Create a new route entry.